Features to add

- provision env on AWS (via terraform)
- deploy to env
- version in file
- multiple env
- publish unit test and code quality reports
- manual approval for prod
- web page
- smoke test
- API test
- UI test